@@ -1,3 +1,3 @@
 from .file_utils import FileHandler
 from .model_utils import copyStateDict
-from .image_utils import loadImage, cvt2HeatmapImg, crop_image
\ No newline at end of file
+from .image_utils import ImageUtils
\ No newline at end of file
